==> tfmake-1.0.10.tar.gz: tfmake-1.0.10/tfmake/cli.py <==
import os
import click
from jinja2 import Environment, PackageLoader
import yaml
import json

from tfmake import __version__

from tfmake.custom import DefaultCommandHandler, DefaultCommandGroup

env = Environment(
    loader=PackageLoader('tfmake', 'templates')
)

@click.group(cls=DefaultCommandGroup)
@click.version_option(version=__version__)
def main():
    pass

@main.command(name='azure')
@click.argument('target', default='help')
@click.argument('args', nargs=-1)
def azure(target, args):
    '''
    Use Azure provider
    '''
    DefaultCommandHandler('azure').call(target, args)

@main.command(name='guess', default_command=True)
@click.argument('target', default='help')
@click.argument('args', nargs=-1)
def guess(target, args):
    '''
    Default command that guesses what provider you're using.
    '''
    DefaultCommandHandler().call(target, args)

@main.command(name='aws')
@click.argument('target', default='help')
@click.argument('args', nargs=-1)
def aws(target, args):
    '''
    Use AWS provider.
    '''
    DefaultCommandHandler('aws').call(target, args)

@main.command()
@click.argument('provider', default='aws')
def init(provider):
    '''
    Create configuration for provider (migrate if needed).
    '''
    legacy = None
    cwd = os.path.join(os.getcwd(), '.tfmake')
    if os.path.isfile(cwd):
        if click.confirm('Legacy configuration found! Do you want me to migrate?', default=True):
            with open(cwd,'r') as f:
                legacy = f.read()
            os.rename(cwd, '{}.bkp'.format(cwd))

    if not os.path.isdir(cwd):
        os.mkdir(cwd)

    config = os.path.join(cwd, "config")
    if os.path.isfile(config):
        click.confirm('Existing configuration found! Do you want to continue?', abort=True)

    # Get provider-specific template (this is for future use ... not used yet)
    template = env.get_template('tfmake.{}.j2'.format(provider))

    contents = legacy if legacy else template.render(provider=provider)

    with open(config, 'w+') as f:
        f.write(contents)

    if os.path.isfile('{}.bkp'.format(cwd)):
        if click.confirm('\n\nSuccessfully migrated configuration. Delete backup?', default=True):
            os.remove('{}.bkp'.format(cwd))

    click.echo("\nConfiguration written to '{}'".format(config))

if __name__ == '__main__':
    main()

==> tfmake-1.0.12.tar.gz: tfmake-1.0.12/tfmake/cli.py <==
import os
import click
from jinja2 import Environment, PackageLoader
import yaml
import json

from tfmake import __version__

from tfmake.custom import DefaultCommandHandler, DefaultCommandGroup

env = Environment(
    loader=PackageLoader('tfmake', 'templates')
)

@click.group(cls=DefaultCommandGroup)
@click.version_option(version=__version__)
def main():
    pass

@main.command(name='azure')
@click.argument('target', default='help')
@click.argument('args', nargs=-1)
def azure(target, args):
    '''
    Use Azure provider
    '''
    DefaultCommandHandler('azure').call(target, args)

@main.command(name='guess', default_command=True)
@click.argument('target', default='help')
@click.argument('args', nargs=-1)
def guess(target, args):
    '''
    Default command that guesses what provider you're using.
    '''
    DefaultCommandHandler().call(target, args)

@main.command(name='aws')
@click.argument('target', default='help')
@click.argument('args', nargs=-1)
def aws(target, args):
    '''
    Use AWS provider.
    '''
    DefaultCommandHandler('aws').call(target, args)

@main.command()
@click.argument('provider', default='aws')
def init(provider):
    '''
    Create configuration for provider (migrate if needed).
    '''
    legacy = None
    cwd = os.path.join(os.getcwd(), '.tfmake')
    if os.path.isfile(cwd):
        if click.confirm('Legacy configuration found! Do you want me to migrate?', default=True):
            with open(cwd,'r') as f:
                legacy = f.read()

        os.rename(cwd, '{}.bkp'.format(cwd))

    if not os.path.isdir(cwd):
        os.mkdir(cwd)

    config = os.path.join(cwd, "config")
    if os.path.isfile(config):
        click.confirm('Existing configuration found! Do you want to continue?', abort=True)

    # Get provider-specific template (this is for future use ... not used yet)
    template = env.get_template('tfmake.{}.j2'.format(provider))

    contents = legacy if legacy else template.render(provider=provider)

    with open(config, 'w+') as f:
        f.write(contents)

    if not legacy and os.path.isfile('{}.bkp'.format(cwd)):
        if click.confirm('\n\nSuccessfully migrated configuration. Delete backup?', default=True):
            os.remove('{}.bkp'.format(cwd))

    click.echo("\nConfiguration written to '{}'".format(config))

if __name__ == '__main__':
    main()
